@@ -64,17 +64,11 @@ GtkWidget * create_fake_menu (GMenuTreeDirectory *directory)
 				   submenu_to_display_in_idle,
 				   menu,
 				   NULL);
-	if (myData.iSidFakeMenuIdle != 0)
-		g_source_remove (myData.iSidFakeMenuIdle);
-	myData.iSidFakeMenuIdle = idle_id;
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-idle-id",
 				GUINT_TO_POINTER (idle_id),
 				remove_submenu_to_display_idle);
 
-	g_signal_connect (menu, "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
-
 	return menu;
 }
 
@@ -92,8 +86,9 @@ static void reload_image_menu_items (void)
 		GtkWidget *image = l->data;
 		gboolean   is_mapped;
       
-		is_mapped = GTK_WIDGET_MAPPED (image);
-
+		///is_mapped = GTK_WIDGET_MAPPED (image);
+		is_mapped = gtk_widget_get_mapped (image);
+		
 		if (is_mapped)
 			gtk_widget_unmap (image);
 
@@ -235,50 +230,47 @@ GdkPixbuf * panel_make_menu_icon (GtkIconTheme *icon_theme,
 
 void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 				GtkIconSize  icon_size,
-				const char  *stock_id,
-				GIcon       *gicon,
+				///const char  *stock_id,
+				///GIcon       *gicon,
 				const char  *image_filename,
 				const char  *fallback_image_filename)
 {
 	IconToLoad *icon;
 	GtkWidget *image;
-	int        icon_height = PANEL_DEFAULT_MENU_ICON_SIZE;
+	int        icon_height = myData.iPanelDefaultMenuIconSize;
 
-	icon = g_new (IconToLoad, 1);
+	icon = g_new0 (IconToLoad, 1);
 
 	gtk_icon_size_lookup (icon_size, NULL, &icon_height);
 
 	image = gtk_image_new ();
-	image->requisition.width  = icon_height;
-	image->requisition.height = icon_height;
-
+	///image->requisition.width  = icon_height;
+	///image->requisition.height = icon_height;
+	gtk_widget_set_size_request (image, icon_height, icon_height);
+	
 	/* this takes over the floating ref */
 	icon->pixmap = g_object_ref (G_OBJECT (image));
-	gtk_object_sink (GTK_OBJECT (image));
+	g_object_ref_sink (G_OBJECT (image));
 
-	icon->stock_id       = stock_id;
+	/**icon->stock_id       = stock_id;
 	if (gicon)
 		icon->gicon  = g_object_ref (gicon);
 	else
-		icon->gicon  = NULL;
+		icon->gicon  = NULL;*/
 	icon->image          = g_strdup (image_filename);
 	icon->fallback_image = g_strdup (fallback_image_filename);
 	icon->icon_size      = icon_size;
 
 	gtk_widget_show (image);
 
-	g_object_set_data_full (G_OBJECT (image_menu_item),
+	/**g_object_set_data_full (G_OBJECT (image_menu_item),
 				"Panel:Image",
 				g_object_ref (image),
-				(GDestroyNotify) g_object_unref);
+				(GDestroyNotify) g_object_unref);*/
  
 	if (myConfig.bHasIcons)
 	{
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-		gtk_image_menu_item_set_always_show_image (
-			GTK_IMAGE_MENU_ITEM (image_menu_item), TRUE);
-#endif
-		gtk_image_menu_item_set_image (
+		_gtk_image_menu_item_set_image (
 			GTK_IMAGE_MENU_ITEM (image_menu_item), image);
 	}
 
@@ -300,13 +292,13 @@ GtkWidget * create_submenu_entry (GtkWidget          *menu,
 
 	panel_load_menu_image_deferred (menuitem,
 					32, //panel_menu_icon_get_size (),
-					NULL, NULL,
+					///NULL, NULL,
 					gmenu_tree_directory_get_icon (directory),
 					PANEL_ICON_FOLDER);
 
 	setup_menuitem (menuitem,
 			32, //panel_menu_icon_get_size (),
-			NULL,
+			///NULL,
 			gmenu_tree_directory_get_name (directory));
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -374,15 +366,15 @@ void create_menuitem (GtkWidget          *menu,
 					(GDestroyNotify) gmenu_tree_item_unref);
 
 	panel_load_menu_image_deferred (menuitem,
-					PANEL_DEFAULT_MENU_ICON_SIZE, //panel_menu_icon_get_size (),
-					NULL, NULL,
+					myData.iPanelDefaultMenuIconSize, //panel_menu_icon_get_size (),
+					///NULL, NULL,
 					alias_directory ? gmenu_tree_directory_get_icon (alias_directory) :
 							  gmenu_tree_entry_get_icon (entry),
 					NULL);
 
 	setup_menuitem (menuitem,
-			PANEL_DEFAULT_MENU_ICON_SIZE, //panel_menu_icon_get_size (),
-			NULL,
+			myData.iPanelDefaultMenuIconSize, //panel_menu_icon_get_size (),
+			///NULL,
 			alias_directory ? gmenu_tree_directory_get_name (alias_directory) :
 					  gmenu_tree_entry_get_name (entry));
 
@@ -422,12 +414,12 @@ void create_menuitem (GtkWidget          *menu,
 			}
 		}
 
-		g_signal_connect (G_OBJECT (menuitem), "drag_begin",
-				  G_CALLBACK (drag_begin_menu_cb), NULL);
+		///g_signal_connect (G_OBJECT (menuitem), "drag_begin",
+		///		  G_CALLBACK (drag_begin_menu_cb), NULL);
 		g_signal_connect (menuitem, "drag_data_get",
 				  G_CALLBACK (drag_data_get_menu_cb), entry);
-		g_signal_connect (menuitem, "drag_end",
-				  G_CALLBACK (drag_end_menu_cb), NULL);
+		///g_signal_connect (menuitem, "drag_end",
+		///		  G_CALLBACK (drag_end_menu_cb), NULL);
 	}
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -466,7 +458,7 @@ void create_menuitem_from_alias (GtkWidget      *menu,
 }
 
 
-static void
+/**static void
 image_menuitem_size_request (GtkWidget      *menuitem,
 			     GtkRequisition *requisition,
 			     gpointer        data)
@@ -478,20 +470,19 @@ image_menuitem_size_request (GtkWidget      *menuitem,
 	if (!gtk_icon_size_lookup (icon_size, NULL, &icon_height))
 		return;
 
-	/* If we don't have a pixmap for this menuitem
-	 * at least make sure its the same height as
-	 * the rest.
-	 * This is a bit ugly, since we should keep this in sync with what's in
-	 * gtk_menu_item_size_request()
-	 */
+	// If we don't have a pixmap for this menuitem
+	// at least make sure its the same height as
+	// the rest.
+	// This is a bit ugly, since we should keep this in sync with what's in
+	// gtk_menu_item_size_request()
 	req_height = icon_height;
 	req_height += (GTK_CONTAINER (menuitem)->border_width +
-		       menuitem->style->ythickness) * 2;
+		       menuitem->style->thickness) * 2;
 	requisition->height = MAX (requisition->height, req_height);
-}
+}*/
 void setup_menuitem (GtkWidget   *menuitem,
 		GtkIconSize  icon_size,
-		GtkWidget   *image,
+		///GtkWidget   *image,
 		const char  *title)
 			       
 {
@@ -513,7 +504,7 @@ void setup_menuitem (GtkWidget   *menuitem,
 
 	gtk_container_add (GTK_CONTAINER (menuitem), label);
 
-	if (image) {
+	/**if (image) {
 		g_object_set_data_full (G_OBJECT (menuitem),
 					"Panel:Image",
 					g_object_ref (image),
@@ -521,18 +512,14 @@ void setup_menuitem (GtkWidget   *menuitem,
 		gtk_widget_show (image);
 		if (myConfig.bHasIcons)
 		{
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-			gtk_image_menu_item_set_always_show_image (
-				GTK_IMAGE_MENU_ITEM (menuitem), TRUE);
-#endif
-			gtk_image_menu_item_set_image (
+			_gtk_image_menu_item_set_image (
 				GTK_IMAGE_MENU_ITEM (menuitem), image);
 		}
 	} else if (icon_size != GTK_ICON_SIZE_INVALID)
 		g_signal_connect (menuitem, "size_request",
 				  G_CALLBACK (image_menuitem_size_request),
 				  GINT_TO_POINTER (icon_size));
-
+	*/
 	gtk_widget_show (menuitem);
 }
 
@@ -543,8 +530,11 @@ GtkWidget * populate_menu_from_directory (GtkWidget          *menu,
 	GSList   *items;
 	gboolean  add_separator;
 
-	add_separator = (GTK_MENU_SHELL (menu)->children != NULL);
-
+	///add_separator = (GTK_MENU_SHELL (menu)->children != NULL);
+	GList *children = gtk_container_get_children (GTK_CONTAINER (menu));
+	add_separator = (children != NULL);
+	g_list_free (children);  // not very optimized ...	
+	
 	items = gmenu_tree_directory_get_contents (directory);
 
 	for (l = items; l; l = l->next) {
@@ -597,7 +587,7 @@ void icon_theme_changed (GtkIconTheme *icon_theme,
 	reload_image_menu_items ();
 }
 
-GtkWidget * panel_create_menu (void)
+static inline GtkWidget * panel_create_menu (void)
 {
 	GtkWidget       *retval;
 	static gboolean  registered_icon_theme_changer = FALSE;
@@ -611,14 +601,6 @@ GtkWidget * panel_create_menu (void)
 	
 	retval = gtk_menu_new ();
 	
-	/*panel_gconf_notify_add_while_alive ("/desktop/gnome/interface/menus_have_icons",
-					    (GConfClientNotifyFunc) menus_have_icons_changed,
-					    G_OBJECT (retval));*/
-
-	/*g_signal_connect (retval, "key_press_event",
-			  G_CALLBACK (panel_menu_key_press_handler),
-			  NULL);*/
-
 	return retval;
 }
 GtkWidget * create_empty_menu (void)
@@ -627,13 +609,6 @@ GtkWidget * create_empty_menu (void)
 
 	retval = panel_create_menu ();
 
-	//g_signal_connect (retval, "show", G_CALLBACK (setup_menu_panel), NULL);
-
-	/* intercept all right button clicks makes sure they don't
-	   go to the object itself */
-	g_signal_connect (retval, "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
-
 	return retval;
 }
 
@@ -669,7 +644,8 @@ GtkWidget * create_applications_menu (const char *menu_file,
 	g_object_set_data (G_OBJECT (menu),
 			   "panel-menu-needs-loading",
 			   GUINT_TO_POINTER (TRUE));
-
+	
+	// load the menu in idle, and force the loading if it's shown before.
 	g_signal_connect (menu, "show",
 			  G_CALLBACK (submenu_to_display), NULL);
 
@@ -677,17 +653,11 @@ GtkWidget * create_applications_menu (const char *menu_file,
 				   submenu_to_display_in_idle,
 				   menu,
 				   NULL);
-	if (myData.iSidCreateMenuIdle != 0)
-		g_source_remove (myData.iSidCreateMenuIdle);
-	myData.iSidCreateMenuIdle = idle_id;
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-idle-id",
 				GUINT_TO_POINTER (idle_id),
 				remove_submenu_to_display_idle);
 
-	g_signal_connect (menu, "button_press_event",
-			  G_CALLBACK (menu_dummy_button_press_event), NULL);
-
 	gmenu_tree_add_monitor (tree,
 			       (GMenuTreeChangedFunc) handle_gmenu_tree_changed,
 			       menu);
@@ -699,19 +669,43 @@ GtkWidget * create_applications_menu (const char *menu_file,
 	return menu;
 }
 
+#define XDG_MENUS_PATH "/etc/xdg/menus"
 GtkWidget * create_main_menu (CairoDockModuleInstance *myApplet)
 {
 	GtkWidget *main_menu;
 	
 	// workaround pour KDE, qui ne loupe pas une occasion de se distinguer.
 	const gchar *cMenuFileName = NULL;
-	if (! g_file_test ("/etc/xdg/menus/applications.menu", G_FILE_TEST_EXISTS))  // on pourrait aussi aller lire le start-here.menu, mais je suis pas sur que ce soit standard.
+	if (g_file_test (XDG_MENUS_PATH"/applications.menu", G_FILE_TEST_EXISTS))  // first check 
+		cMenuFileName = "applications.menu";
+	else if (g_file_test (XDG_MENUS_PATH"/gnome-applications.menu", G_FILE_TEST_EXISTS))
+		cMenuFileName = "gnome-applications.menu";
+	else if (g_file_test (XDG_MENUS_PATH"/kde-applications.menu", G_FILE_TEST_EXISTS))
+		cMenuFileName = "kde-applications.menu";
+	else if (g_file_test (XDG_MENUS_PATH"/kde4-applications.menu", G_FILE_TEST_EXISTS))
+		cMenuFileName = "kde4-applications.menu";
+	else if (g_file_test (XDG_MENUS_PATH"/xfce-applications.menu", G_FILE_TEST_EXISTS))
+		cMenuFileName = "xfce-applications.menu";
+	else if (g_file_test (XDG_MENUS_PATH"/lxde-applications.menu", G_FILE_TEST_EXISTS))
+		cMenuFileName = "lxde-applications.menu";
+	else  // let's check any *-applications.menu
 	{
-		if (g_file_test ("/etc/xdg/menus/kde-applications.menu", G_FILE_TEST_EXISTS))
-			cMenuFileName = "kde-applications.menu";
-		else if (g_file_test ("/etc/xdg/menus/xfce-applications.menu", G_FILE_TEST_EXISTS))
-			cMenuFileName = "xfce-applications.menu";
+		const gchar *cFileName;
+		GDir *dir = g_dir_open (XDG_MENUS_PATH, 0, NULL);
+		if (dir)
+		{
+			while (cFileName = g_dir_read_name (dir))
+			{
+				if (g_str_has_suffix (cFileName, "-applications.menu"))
+				{
+					cMenuFileName = cFileName;
+					break;
+				}
+			}
+			g_dir_close (dir);
+		}
 	}
+	
 	if (cMenuFileName == NULL)
 		cMenuFileName = "applications.menu";
 	
