@@ -23,14 +23,30 @@
 #include <glib/gi18n.h>
 
 #include "applet-struct.h"
-#include "applet-mixer.h"
+#include "applet-generic.h"
 #include "applet-notifications.h"
 
+static const gchar *s_cMixerCmd = NULL;
+static gboolean bMixerChecked = FALSE;
 
 CD_APPLET_ON_CLICK_BEGIN
-	mixer_show_hide_dialog ();
+	cd_show_hide ();
 CD_APPLET_ON_CLICK_END
 
+static void _check_mixer_cmd (void)
+{
+	gchar *cResult = cairo_dock_launch_command_sync ("which gnome-control-center");  // Gnome3
+	if (cResult != NULL && *cResult == '/')
+		s_cMixerCmd = "gnome-control-center sound";
+	else
+	{
+		g_free (cResult);
+		cResult = cairo_dock_launch_command_sync ("which gnome-volume-control");  // Gnome2
+		if (cResult != NULL && *cResult == '/')  /// TODO: other DE...
+			s_cMixerCmd = "gnome-volume-control -p applications";
+	}  /// TODO: handle other DE ...
+	g_free (cResult);
+}
 
 static void _mixer_show_advanced_mixer (GtkMenuItem *menu_item, gpointer data)
 {
@@ -40,9 +56,9 @@ static void _mixer_show_advanced_mixer (GtkMenuItem *menu_item, gpointer data)
 	{
 		g_spawn_command_line_async (myConfig.cShowAdvancedMixerCommand, &erreur);
 	}
-	else
+	else if (s_cMixerCmd != NULL)
 	{
-		g_spawn_command_line_async ("gnome-volume-control -p applications", &erreur);
+		g_spawn_command_line_async (s_cMixerCmd, &erreur);
 	}
 	
 	if (erreur != NULL)
@@ -53,50 +69,60 @@ static void _mixer_show_advanced_mixer (GtkMenuItem *menu_item, gpointer data)
 	CD_APPLET_LEAVE();
 }
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	// Main Menu
 	gchar *cLabel;
-	cLabel = g_strdup_printf ("%s (%s)", D_("Adjust channels"), D_("double-click"));
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_PREFERENCES, _mixer_show_advanced_mixer, CD_APPLET_MY_MENU);
-	g_free (cLabel);
+	
+	if (!myConfig.cShowAdvancedMixerCommand && !bMixerChecked)
+	{
+		bMixerChecked = TRUE;
+		_check_mixer_cmd ();
+	}
+	
+	if (myConfig.cShowAdvancedMixerCommand || s_cMixerCmd)
+	{
+		cLabel = g_strdup_printf ("%s (%s)", D_("Adjust channels"), D_("double-click"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_PREFERENCES, _mixer_show_advanced_mixer, CD_APPLET_MY_MENU);
+		g_free (cLabel);
+	}
+	
 	cLabel = g_strdup_printf ("%s (%s)", (myData.bIsMute ? D_("Unmute") : D_("Mute")), D_("middle-click"));
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, MY_APPLET_SHARE_DATA_DIR"/emblem-mute.svg", mixer_switch_mute, CD_APPLET_MY_MENU);
+	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, MY_APPLET_SHARE_DATA_DIR"/emblem-mute.svg", cd_toggle_mute, CD_APPLET_MY_MENU);
 	g_free (cLabel);
-	// Sub-Menu
-	CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
 
 
 CD_APPLET_ON_MIDDLE_CLICK_BEGIN
-	mixer_switch_mute ();
+	cd_toggle_mute ();
 CD_APPLET_ON_MIDDLE_CLICK_END
 
 
 CD_APPLET_ON_DOUBLE_CLICK_BEGIN
+	if (!myConfig.cShowAdvancedMixerCommand && !bMixerChecked)
+	{
+		bMixerChecked = TRUE;
+		_check_mixer_cmd (); // looking for s_cMixerCmd
+	}
 	_mixer_show_advanced_mixer (NULL, NULL);
 CD_APPLET_ON_DOUBLE_CLICK_END
 
 
+CD_APPLET_ON_SCROLL_BEGIN
+	double delta;
+	if (CD_APPLET_SCROLL_UP)
+		delta = myConfig.iScrollVariation;
+	else
+		delta = - myConfig.iScrollVariation;
+	
+	int iVolume = cd_get_volume ();
+	
+	iVolume = MAX (0, MIN (iVolume + delta, 100));
+	
+	cd_set_volume (iVolume);
+CD_APPLET_ON_SCROLL_END
+
+
 void mixer_on_keybinding_pull (const char *keystring, gpointer user_data)
 {
 	CD_APPLET_ENTER;
-	mixer_show_hide_dialog ();
+	cd_show_hide ();
 	CD_APPLET_LEAVE();
 }
-
-CD_APPLET_ON_SCROLL_BEGIN
-	int iVolume = mixer_get_mean_volume ();  // [0;100]
-	double delta = myConfig.iScrollVariation;
-	if (CD_APPLET_SCROLL_DOWN)
-	{
-		iVolume = MAX (iVolume - delta, 0);
-	}
-	else if (CD_APPLET_SCROLL_UP)
-	{
-		iVolume = MIN (iVolume + delta, 100);
-	}
-	else
-		CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
-	
-	mixer_set_volume (iVolume);
-CD_APPLET_ON_SCROLL_END
