@@ -277,8 +277,6 @@ gboolean cd_clock_update_with_time (CairoDockModuleInstance *myApplet)
 				fScale,
 				iWidth,
 				&myData.iDateWidth, &myData.iDateHeight);
-			myData.iDateWidth *= fScale;
-			myData.iDateHeight *= fScale;
 			//g_print ("date : %dx%d\n", myData.iDateWidth, myData.iDateHeight);
 			myData.iDateTexture = cairo_dock_create_texture_from_surface (pDateSurface);
 			cairo_surface_destroy (pDateSurface);
