@@ -51,6 +51,20 @@ owned =>
 not owned => stop handler
 */
 
+static inline void _fill_handler_properties (const gchar *cDesktopFileName)
+{
+	g_free ((gchar*)myData.pCurrentHandler->appclass);
+	myData.pCurrentHandler->appclass = cairo_dock_register_class (cDesktopFileName);
+	g_free ((gchar*)myData.pCurrentHandler->launch);
+	myData.pCurrentHandler->launch = g_strdup (cairo_dock_get_class_command (myData.pCurrentHandler->appclass));
+	if (myData.pCurrentHandler->launch == NULL)  // we really need a command to launch it on click, so insist a little
+	{
+		myData.pCurrentHandler->launch = g_strdup (cDesktopFileName);
+	}
+	g_free ((gchar*)myData.pCurrentHandler->cDisplayedName);
+	myData.pCurrentHandler->cDisplayedName = g_strdup (cairo_dock_get_class_name (myData.pCurrentHandler->appclass));
+}
+
 MusicPlayerHandler *cd_musicplayer_get_handler_by_name (const gchar *cName)
 {
 	g_return_val_if_fail (cName != NULL, NULL);
@@ -299,14 +313,7 @@ static void _on_got_desktop_entry (DBusGProxy *proxy, DBusGProxyCall *call_id, g
 				myConfig.cLastKnownDesktopFile = g_strdup (cDesktopFileName);
 				
 				// register the desktop file, and get the common properties of this class.
-				g_free ((gchar*)myData.pCurrentHandler->launch);
-				g_free ((gchar*)myData.pCurrentHandler->appclass);
-				g_free ((gchar*)myData.pCurrentHandler->cDisplayedName);
-				
-				myData.pCurrentHandler->appclass = cairo_dock_register_class (cDesktopFileName);
-				myData.pCurrentHandler->launch = g_strdup (cairo_dock_get_class_command (myData.pCurrentHandler->appclass));
-				myData.pCurrentHandler->cDisplayedName = g_strdup (cairo_dock_get_class_name (myData.pCurrentHandler->appclass));
-				cd_debug ("  class is now '%s'", myData.pCurrentHandler->appclass);
+				_fill_handler_properties (cDesktopFileName);
 				
 				if (myData.pCurrentHandler->appclass != NULL)
 				{
@@ -346,6 +353,15 @@ static void _on_name_owner_changed (const gchar *cName, gboolean bOwned, gpointe
 				// set the MPRIS2 handler as the current one
 				myData.pCurrentHandler = cd_musicplayer_get_handler_by_name ("Mpris2");  // no need to watch it, it was already done (that's why we are here !)
 				
+				// fill its properties
+				myData.pCurrentHandler->appclass = cairo_dock_register_class (myConfig.cLastKnownDesktopFile ? myConfig.cLastKnownDesktopFile : cName);  // myConfig.cLastKnownDesktopFile is NULL when transitionning from an old version of the applet where we didn't use the "Desktop Entry" property yet -> use some heuristic as a fallback.
+				myData.pCurrentHandler->launch = g_strdup (cairo_dock_get_class_command (myData.pCurrentHandler->appclass));
+				myData.pCurrentHandler->cDisplayedName = g_strdup (cairo_dock_get_class_name (myData.pCurrentHandler->appclass));
+				if (myData.pCurrentHandler->launch == NULL)  // we really need a command to launch it on click, so insist a little
+				{
+					myData.pCurrentHandler->launch = g_strdup (cName);
+				}
+				
 				g_free ((gchar*)myData.pCurrentHandler->cMprisService);
 				myData.pCurrentHandler->cMprisService = g_strdup (cName);
 			}
@@ -378,7 +394,7 @@ static void _on_name_owner_changed (const gchar *cName, gboolean bOwned, gpointe
 	}
 	else  // else stop the handler.
 	{
-		cd_debug ("stop the handler");
+		cd_debug ("stop the handler {%s, %s}", myData.pCurrentHandler->name, myData.pCurrentHandler->launch);
 		cd_musicplayer_stop_current_handler (FALSE);  // FALSE = keep watching it.
 		cd_musicplayer_apply_status_surface (PLAYER_NONE);
 		if (myConfig.cDefaultTitle != NULL)
@@ -395,6 +411,7 @@ static void _on_name_owner_changed (const gchar *cName, gboolean bOwned, gpointe
 			{
 				CD_APPLET_SET_NAME_FOR_MY_ICON (myData.pCurrentHandler->name);
 			}
+		cd_debug ("stopped {%s, %s}", myData.pCurrentHandler->name, myData.pCurrentHandler->launch);
 		}
 	}
 	CD_APPLET_LEAVE ();
@@ -456,7 +473,7 @@ void cd_musicplayer_set_current_handler (const gchar *cName)
 		
 		cairo_dock_watch_dbus_name_owner (myData.cMpris2Service, (CairoDockDbusNameOwnerChangedFunc) _on_name_owner_changed, NULL);
 		
-		myData.pDetectPlayerCall = cairo_dock_dbus_detect_application_async (myData.cMpris2Service, (CairoDockOnAppliPresentOnDbus) _on_detect_mpris2, NULL);  // mpris2 first, and then the other one.	
+		myData.pDetectPlayerCall = cairo_dock_dbus_detect_application_async (myData.cMpris2Service, (CairoDockOnAppliPresentOnDbus) _on_detect_mpris2, NULL);  // mpris2 first, and then the other one.
 	}
 	else  // no such handler, make an MPRIS2 service with this name.
 	{
@@ -464,22 +481,8 @@ void cd_musicplayer_set_current_handler (const gchar *cName)
 		myData.pCurrentHandler = cd_musicplayer_get_handler_by_name ("Mpris2");
 		
 		// fill its properties
-		if (myConfig.cLastKnownDesktopFile != NULL)
-		{
-			myData.pCurrentHandler->appclass = cairo_dock_register_class (myConfig.cLastKnownDesktopFile);
-			myData.pCurrentHandler->launch = g_strdup (cairo_dock_get_class_command (myData.pCurrentHandler->appclass));
-			myData.pCurrentHandler->cDisplayedName = g_strdup (cairo_dock_get_class_name (myData.pCurrentHandler->appclass));
-		}
-		else  // can happen when transitionning from an old version of the applet where we didn't use the "Desktop Entry" property yet -> use some heuristic as a fallback.
-		{
-			myData.pCurrentHandler->appclass = cairo_dock_register_class (cName);
-			myData.pCurrentHandler->launch = g_strdup (cairo_dock_get_class_command (myData.pCurrentHandler->appclass));
-			myData.pCurrentHandler->cDisplayedName = g_strdup (cairo_dock_get_class_name (myData.pCurrentHandler->appclass));
-			if (myData.pCurrentHandler->launch == NULL)  // we really need a command to launch it on click, so insist a little
-			{
-				myData.pCurrentHandler->launch = g_strdup (cName);
-			}
-		}
+		_fill_handler_properties (myConfig.cLastKnownDesktopFile ? myConfig.cLastKnownDesktopFile : cName);  // myConfig.cLastKnownDesktopFile is NULL when transitionning from an old version of the applet where we didn't use the "Desktop Entry" property yet -> use some heuristic as a fallback.
+		
 		myData.pCurrentHandler->cMprisService = g_strdup_printf (CD_MPRIS2_SERVICE_BASE".%s", cName);
 		myData.cMpris2Service = NULL;
 	}
@@ -520,6 +523,11 @@ void cd_musicplayer_set_current_handler (const gchar *cName)
 	}
 	
 	// manage its taskbar icon.
+	if (myData.pCurrentHandler->appclass != NULL)
+	{
+		cairo_dock_set_data_from_class (myData.pCurrentHandler->appclass, myIcon);
+	}
+	
 	if (myConfig.bStealTaskBarIcon)
 		CD_APPLET_MANAGE_APPLICATION (myData.pCurrentHandler->appclass);
 }
