@@ -49,6 +49,10 @@ void cd_systray_build_systray (void)
 	
 	myData.tray = na_tray_new_for_screen (gtk_widget_get_screen (GTK_WIDGET (myContainer->pWidget)),
 		myConfig.iIconPacking == 0 ? GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL);
+	#if (GTK_MAJOR_VERSION > 2)
+	na_tray_set_icon_size (myData.tray, 24);
+	na_tray_set_padding (myData.tray, 3);
+	#endif
 	
 	if (myDock)
 	{
@@ -60,8 +64,6 @@ void cd_systray_build_systray (void)
 		CD_APPLET_SET_DESKLET_RENDERER (NULL);
 	}
 	gtk_widget_show (GTK_WIDGET (myData.tray));
-	
-	systray_set_shortcut ();
 }
 
 
@@ -85,11 +87,6 @@ void systray_on_keybinding_pull (const char *keystring, gpointer user_data)
 	}
 }
 
-void systray_set_shortcut (void)
-{
-	cd_keybinder_bind (myConfig.shortcut, (CDBindkeyHandler)systray_on_keybinding_pull, 0);
-}
-
 
 void cd_systray_set_orientation (GtkOrientation o)
 {
