@@ -29,6 +29,7 @@
 #include <gdk/gdkkeysyms.h>
 // gdk.h semble necessaire pour certains
 #include <gdk/gdk.h>
+#include <gdk/gdkx.h>
 
 #include <vte/vte.h>
 
@@ -37,6 +38,10 @@
 #include "terminal-menu-functions.h"
 #include "terminal-widget.h"
 
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 20)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
+
 void cd_terminal_grab_focus (void)
 {
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK(myData.tab));
@@ -60,7 +65,7 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	{
 		if (myDesklet)
 		{
-			gboolean bHasFocus = (gtk_window_has_toplevel_focus (GTK_WINDOW (myDesklet->container.pWidget)) || GTK_WIDGET_HAS_FOCUS (myData.tab) || GTK_WIDGET_HAS_FOCUS (myDesklet->container.pWidget));
+			gboolean bHasFocus = (gtk_window_has_toplevel_focus (GTK_WINDOW (myDesklet->container.pWidget)) || gtk_widget_has_focus (myData.tab) || gtk_widget_has_focus (myDesklet->container.pWidget));
 			if (! bHasFocus)
 			{
 				GtkWidget *vterm;
@@ -68,9 +73,9 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 				for (i = 0; i < iNbPages && ! bHasFocus; ++i)
 				{
 					vterm = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
-					bHasFocus = GTK_WIDGET_HAS_FOCUS (vterm);
+					bHasFocus = gtk_widget_has_focus (vterm);
 				}
-				bHasFocus |= (GDK_WINDOW_XID (myDesklet->container.pWidget->window) == cairo_dock_get_current_active_window ());
+				bHasFocus |= (gldi_container_get_Xid (myContainer) == cairo_dock_get_current_active_window ());
 			}
 			cd_debug ("%s (%d)\n", __func__, bHasFocus);
 			
@@ -86,7 +91,7 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 		}
 		else if (myData.dialog)
 		{
-			if (GTK_WIDGET_VISIBLE (myData.dialog->container.pWidget))
+			if (gldi_container_is_visible (CAIRO_CONTAINER (myData.dialog)))
 			{
 				cairo_dock_hide_dialog (myData.dialog);
 			}
@@ -208,6 +213,7 @@ void terminal_change_color_tab (GtkWidget *vterm)
 		GtkLabel *pLabel = pTabWidgetList->data;
 		
 		GtkWidget *pColorDialog = gtk_color_selection_dialog_new (D_("Select a color"));
+		GtkWidget *colorsel = gtk_color_selection_dialog_get_color_selection ((GtkColorSelectionDialog *) pColorDialog);
 		
 		const gchar *cCurrentLabel = gtk_label_get_text (pLabel);
 		GdkColor color;
@@ -215,14 +221,19 @@ void terminal_change_color_tab (GtkWidget *vterm)
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, &color, &bColorSet);
 		if (bColorSet)
 		{
-			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (((GtkColorSelectionDialog *) pColorDialog)->colorsel), &color);
+			
+			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (colorsel), &color);
 		}
 		
-		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (((GtkColorSelectionDialog *) pColorDialog)->colorsel), FALSE);
-		g_signal_connect (((GtkColorSelectionDialog *) pColorDialog)->colorsel, "color-changed", GTK_SIGNAL_FUNC (_set_color), pLabel);
+		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (colorsel), FALSE);
+		g_signal_connect (colorsel, "color-changed", G_CALLBACK (_set_color), pLabel);
+		#if (GTK_MAJOR_VERSION < 3)
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->cancel_button);
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->help_button);
-		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy), pColorDialog);
+		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", G_CALLBACK (gtk_widget_destroy), pColorDialog);
+		#else
+		/// TODO: alternative for GTK3?...
+		#endif
 		
 		gtk_window_present (GTK_WINDOW (pColorDialog));
 	}
@@ -248,30 +259,31 @@ void terminal_close_tab (GtkWidget *vterm)
 
 static void _term_apply_settings_on_vterm(GtkWidget *vterm)
 {
-  g_return_if_fail (vterm != NULL);
-  vte_terminal_set_colors(VTE_TERMINAL(vterm), &myConfig.forecolor, &myConfig.backcolor, NULL, 0);
-      //vte_terminal_set_background_saturation(VTE_TERMINAL(vterm), 1.0);
-      //vte_terminal_set_background_transparent(VTE_TERMINAL(vterm), TRUE);
-#if GTK_MINOR_VERSION >= 12
-  vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
-#endif
-  
+	g_return_if_fail (vterm != NULL);
+	vte_terminal_set_colors(VTE_TERMINAL(vterm), &myConfig.forecolor, &myConfig.backcolor, NULL, 0);
+	#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 12)
+	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
+	#endif
+	
 	if (myDock)
 	{
-		//g_print ("set_size (%d , %d)\n", myConfig.iNbColumns, myConfig.iNbRows);
-		gtk_widget_set (vterm, "width-request", 0, NULL);
-		gtk_widget_set (vterm, "height-request", 0, NULL);
+		// since dialogs can't be resized (like desklets), set the size as defined in the config.
+		// Note: vte_terminal_set_size() doesn't work since the port to GTK3.
+		#ifdef LIBVTE_IS_NOT_BUGGY
+		g_object_set (vterm, "width-request", 0, NULL);  // reset if ever it was previously set (removing this line doesn't make vte_terminal_set_size() work ...)
+		g_object_set (vterm, "height-request", 0, NULL);
 		vte_terminal_set_size(VTE_TERMINAL(vterm), myConfig.iNbColumns, myConfig.iNbRows);
-		GtkRequisition requisition = {0, 0};
-		gtk_widget_size_request (vterm, &requisition);
-		//g_print (" -> %dx%d\n", requisition.width, requisition.height);
-		if (myData.dialog)
-			gtk_window_resize (GTK_WINDOW (myData.dialog->container.pWidget), requisition.width, requisition.height);
+		#else
+		g_object_set (vterm,
+			"width-request", myConfig.iNbColumns * vte_terminal_get_char_width (VTE_TERMINAL(vterm)),
+			"height-request", myConfig.iNbRows * vte_terminal_get_char_height (VTE_TERMINAL(vterm)),
+			NULL);
+		#endif
 	}
 	else
 	{
-		gtk_widget_set (vterm, "width-request", 64, NULL);
-		gtk_widget_set (vterm, "height-request", 64, NULL);
+		g_object_set (vterm, "width-request", 64, NULL);
+		g_object_set (vterm, "height-request", 64, NULL);
 	}
 }
 
@@ -385,19 +397,13 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 	{
 		menu_item = gtk_image_menu_item_new_with_label (D_("Copy"));
 		image = gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+		_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
 		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_copy), vterm);
 		
 		menu_item = gtk_image_menu_item_new_with_label (D_("Paste"));
 		image = gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+		_gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
 		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
 		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_paste), vterm);
 		
@@ -407,37 +413,25 @@ static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 
   menu_item = gtk_image_menu_item_new_with_label (D_("New Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_new_tab), vterm);
   
   menu_item = gtk_image_menu_item_new_with_label (D_("Rename this Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_rename_tab), vterm);
 
   menu_item = gtk_image_menu_item_new_with_label (D_("Change this Tab's colour"));
   image = gtk_image_new_from_stock (GTK_STOCK_COLOR_PICKER, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_change_tab_color), vterm);
 
   menu_item = gtk_image_menu_item_new_with_label (D_("Close this Tab"));
   image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 16)
-  gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menu_item), TRUE);
-#endif
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
+  _gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
   gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
   g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_close_tab), vterm);
 
@@ -545,16 +539,19 @@ static gchar * _terminal_get_tab_name (int iNumPage)
 	}
 	return NULL;
 }
+
+static AtkObject *
+_get_dummy_accessible(GtkWidget *widget)
+{
+	return NULL;
+}
+
 void terminal_new_tab(void)
 {
 	//\_________________ On cree un nouveau terminal.
 	GtkWidget *vterm = vte_terminal_new();
-	//transparency enable, otherwise we cant change value after
-	//vte_terminal_set_background_transparent(VTE_TERMINAL(vterm), TRUE);
-	#if GTK_MINOR_VERSION >= 12
-	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
-	#endif
-	vte_terminal_set_emulation(VTE_TERMINAL(vterm), "xterm");
+	GTK_WIDGET_GET_CLASS (vterm)->get_accessible = _get_dummy_accessible;  // this is to prevent a bug in libvet2.90; it gives a warning, but it's better than a crash !
+	vte_terminal_set_emulation (VTE_TERMINAL(vterm), "xterm");
 	pid_t pid; 
 	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
 		#if VTE_CHECK_VERSION(0,26,0)
@@ -602,8 +599,8 @@ void terminal_new_tab(void)
 	
 	cairo_dock_allow_widget_to_receive_data (vterm, G_CALLBACK (on_terminal_drag_data_received), NULL);
 
-	GtkWidget *pHBox = gtk_hbox_new (FALSE, 0);
-	
+	GtkWidget *pHBox = _gtk_hbox_new (0);
+
 	//\_________________ On choisit un nom qui ne soit pas deja present, de la forme " # n ".
 	int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK(myData.tab));
 	GList *pTabNameList = NULL;
@@ -658,10 +655,9 @@ void terminal_new_tab(void)
 		0);
 	
 	gtk_widget_show_all (pHBox);
-	int num_new_tab = gtk_notebook_append_page(GTK_NOTEBOOK(myData.tab), vterm, pHBox);
-	GtkWidget *pNewTab = gtk_notebook_get_nth_page (GTK_NOTEBOOK(myData.tab), num_new_tab);
-	
 	gtk_widget_show(vterm);
+	int num_new_tab = gtk_notebook_append_page(GTK_NOTEBOOK(myData.tab), vterm, pHBox);
+	
 	cd_message ("num_new_tab : %d", num_new_tab);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (myData.tab), num_new_tab);
 	
@@ -688,7 +684,7 @@ static void _hide_show_tab_button (GtkNotebook *pNotebook, int iNumPage, gboolea
 	g_list_free (pTabWidgetList);
 }
 static void on_switch_page (GtkNotebook *pNotebook,
-	GtkNotebookPage *pNextPage,
+	GtkWidget *pNextPage,
 	guint iNextNumPage,
 	gpointer user_data)
 {
@@ -706,7 +702,11 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK (myData.tab));
 	pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), iCurrentNumPage);
 	pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
+	#if (GTK_MAJOR_VERSION < 3)
 	gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
+	#else
+	gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
+	#endif
 	iMaxTabHeight = requisition.height;
 	//g_print ("iMaxTabHeight : %d\n", iMaxTabHeight);
 	
@@ -716,7 +716,11 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	{
 		pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
 		pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
+		#if (GTK_MAJOR_VERSION < 3)
 		gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
+		#else
+		gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
+		#endif
 		gtk_widget_translate_coordinates (myData.tab,
 			pTabLabelWidget,
 			x, y,
@@ -804,7 +808,7 @@ void terminal_build_and_show_tab (void)
 	terminal_new_tab();
 	gtk_widget_show(myData.tab);
 
-	term_apply_settings();
+	///term_apply_settings();
 
 	//\_________________ On insere le notebook dans le container.
 	if (myDock)
